package com.fs.doc.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.doc.param.DocOrderReplyQueryParam;
import com.fs.doc.vo.DocOrderReplyListQueryVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.doc.mapper.DocOrderReplyMapper;
import com.fs.doc.domain.DocOrderReply;
import com.fs.doc.service.IDocOrderReplyService;

/**
 * 订单回复Service业务层处理
 * 
 * @author fs
 * @date 2023-01-09
 */
@Service
public class DocOrderReplyServiceImpl implements IDocOrderReplyService 
{
    @Autowired
    private DocOrderReplyMapper docOrderReplyMapper;

    /**
     * 查询订单回复
     * 
     * @param replyId 订单回复ID
     * @return 订单回复
     */
    @Override
    public DocOrderReply selectDocOrderReplyById(Long replyId)
    {
        return docOrderReplyMapper.selectDocOrderReplyById(replyId);
    }

    /**
     * 查询订单回复列表
     * 
     * @param docOrderReply 订单回复
     * @return 订单回复
     */
    @Override
    public List<DocOrderReply> selectDocOrderReplyList(DocOrderReply docOrderReply)
    {
        return docOrderReplyMapper.selectDocOrderReplyList(docOrderReply);
    }

    /**
     * 新增订单回复
     * 
     * @param docOrderReply 订单回复
     * @return 结果
     */
    @Override
    public int insertDocOrderReply(DocOrderReply docOrderReply)
    {
        docOrderReply.setCreateTime(DateUtils.getNowDate());
        return docOrderReplyMapper.insertDocOrderReply(docOrderReply);
    }

    /**
     * 修改订单回复
     * 
     * @param docOrderReply 订单回复
     * @return 结果
     */
    @Override
    public int updateDocOrderReply(DocOrderReply docOrderReply)
    {
        return docOrderReplyMapper.updateDocOrderReply(docOrderReply);
    }

    /**
     * 批量删除订单回复
     * 
     * @param replyIds 需要删除的订单回复ID
     * @return 结果
     */
    @Override
    public int deleteDocOrderReplyByIds(Long[] replyIds)
    {
        return docOrderReplyMapper.deleteDocOrderReplyByIds(replyIds);
    }

    /**
     * 删除订单回复信息
     * 
     * @param replyId 订单回复ID
     * @return 结果
     */
    @Override
    public int deleteDocOrderReplyById(Long replyId)
    {
        return docOrderReplyMapper.deleteDocOrderReplyById(replyId);
    }

    @Override
    public List<DocOrderReplyListQueryVO> selectDocOrderReplyListVOQuery(DocOrderReplyQueryParam param) {
        return docOrderReplyMapper.selectDocOrderReplyListVOQuery(param);
    }
}
